@@ -70,8 +70,6 @@
 #' vector of shares to consider.
 #' @template param_trace
 #'
-#' @template details_online
-#'
 #' @examples
 #' \dontrun{
 #' T <- 50 # Observations
@@ -121,7 +119,8 @@ online <- function(y, experts, tau,
                        sigma = 1,
                        nonc = 0,
                        tailweight = 1,
-                       deg = 1
+                       deg = 1,
+                       periodic = FALSE
                    ),
                    p_smooth_pr = list(
                        knots = P,
@@ -131,7 +130,8 @@ online <- function(y, experts, tau,
                        tailweight = 1,
                        deg = 1,
                        ndiff = 1.5,
-                       lambda = -Inf
+                       lambda = -Inf,
+                       periodic = FALSE
                    ),
                    b_smooth_mv = list(
                        knots = D,
@@ -139,7 +139,8 @@ online <- function(y, experts, tau,
                        sigma = 1,
                        nonc = 0,
                        tailweight = 1,
-                       deg = 1
+                       deg = 1,
+                       periodic = FALSE
                    ),
                    p_smooth_mv = list(
                        knots = D,
@@ -149,7 +150,8 @@ online <- function(y, experts, tau,
                        tailweight = 1,
                        deg = 1,
                        ndiff = 1.5,
-                       lambda = -Inf
+                       lambda = -Inf,
+                       periodic = FALSE
                    ),
                    forget_regret = 0,
                    soft_threshold = -Inf,
@@ -311,7 +313,8 @@ online <- function(y, experts, tau,
         sigma = val_or_def(b_smooth_pr$sigma, 1),
         nonc = val_or_def(b_smooth_pr$nonc, 0),
         tailw = val_or_def(b_smooth_pr$tailweight, 1),
-        deg = val_or_def(b_smooth_pr$deg, 1)
+        deg = val_or_def(b_smooth_pr$deg, 1),
+        periodic = val_or_def(b_smooth_pr$periodic, FALSE)
     )
     pars_basis_pr_n <- prod(sapply(pars_basis_pr, length))
 
@@ -321,7 +324,8 @@ online <- function(y, experts, tau,
         sigma = val_or_def(b_smooth_mv$sigma, 1),
         nonc = val_or_def(b_smooth_mv$nonc, 0),
         tailw = val_or_def(b_smooth_mv$tailweight, 1),
-        deg = val_or_def(b_smooth_mv$deg, 1)
+        deg = val_or_def(b_smooth_mv$deg, 1),
+        periodic = val_or_def(b_smooth_mv$periodic, FALSE)
     )
     pars_basis_mv_n <- prod(sapply(pars_basis_mv, length))
 
@@ -333,7 +337,8 @@ online <- function(y, experts, tau,
         tailw = val_or_def(p_smooth_pr$tailweight, 1),
         deg = val_or_def(p_smooth_pr$deg, 1),
         ndiff = val_or_def(p_smooth_pr$ndiff, 1.5),
-        lambda = val_or_def(p_smooth_pr$lambda, -Inf)
+        lambda = val_or_def(p_smooth_pr$lambda, -Inf),
+        periodic = val_or_def(p_smooth_pr$periodic, FALSE)
     )
     pars_hat_pr_n <- prod(sapply(pars_hat_pr, length))
 
@@ -345,7 +350,8 @@ online <- function(y, experts, tau,
         tailw = val_or_def(p_smooth_mv$tailweight, 1),
         deg = val_or_def(p_smooth_mv$deg, 1),
         ndiff = val_or_def(p_smooth_mv$ndiff, 1.5),
-        lambda = val_or_def(p_smooth_mv$lambda, -Inf)
+        lambda = val_or_def(p_smooth_mv$lambda, -Inf),
+        periodic = val_or_def(p_smooth_mv$periodic, FALSE)
     )
     pars_hat_mv_n <- prod(sapply(pars_hat_mv, length))
 
@@ -382,6 +388,7 @@ online <- function(y, experts, tau,
         nonc = val_or_def(b_smooth_pr$nonc, 0),
         tailw = val_or_def(b_smooth_pr$tailweight, 1),
         deg = val_or_def(b_smooth_pr$deg, 1),
+        periodic = val_or_def(b_smooth_pr$periodic, FALSE),
         idx = sort(unique(parametergrid[, "basis_pr_idx"])),
         params = parametergrids$b_smooth_pr
     )
@@ -397,6 +404,7 @@ online <- function(y, experts, tau,
         nonc = val_or_def(b_smooth_mv$nonc, 0),
         tailw = val_or_def(b_smooth_mv$tailweight, 1),
         deg = val_or_def(b_smooth_mv$deg, 1),
+        periodic = val_or_def(b_smooth_mv$periodic, FALSE),
         idx = sort(unique(parametergrid[, "basis_mv_idx"])),
         params = parametergrids$b_smooth_mv
     )
@@ -413,6 +421,7 @@ online <- function(y, experts, tau,
         deg = val_or_def(p_smooth_pr$deg, 1),
         ndiff = val_or_def(p_smooth_pr$ndiff, 1.5),
         lambda = val_or_def(p_smooth_pr$lambda, -Inf),
+        periodic = val_or_def(p_smooth_pr$periodic, FALSE),
         idx = sort(unique(parametergrid[, "hat_pr_idx"])),
         params = parametergrids$p_smooth_pr
     )
@@ -429,6 +438,7 @@ online <- function(y, experts, tau,
         deg = val_or_def(p_smooth_mv$deg, 1),
         ndiff = val_or_def(p_smooth_mv$ndiff, 1.5),
         lambda = val_or_def(p_smooth_mv$lambda, -Inf),
+        periodic = val_or_def(p_smooth_mv$periodic, FALSE),
         idx = sort(unique(parametergrid[, "hat_mv_idx"])),
         params = parametergrids$p_smooth_mv
     )
